## [0.1.5] - 2026-01-29

### ⚙️ Miscellaneous Tasks

- Fix tags and metadata handling in rules (#12)
## [0.1.4] - 2026-01-28

### 🚀 Features

- Add optimization command (#9)
- Add script for plotting of optimization results (#11)

### ⚙️ Miscellaneous Tasks

- Fix data deduplication in huggingface adapter (#10)
- Prepare v0.1.4
## [0.1.3] - 2026-01-28

### 🚀 Features

- Add support for huggingface config dicts (#1)
- Add scripts for one-off data operations (#2)
- Add deduplication feature (#3)
- Add file logger and improve logging (#6)
- Add generation config file, update cli args, improve logging, improve documentation (#8)

### ⚙️ Miscellaneous Tasks

- Update filter arg for generate command
- Refactor args code (#4)
- Fix logger and update readme (#5)
- Prepare v0.1.2
- Refactor file structure, constants, and streaming logic (#7)
- Prepare v0.1.3
## [0.1.1] - 2026-01-26

### 📚 Documentation

- Update readme and link blog post

### ⚙️ Miscellaneous Tasks

- Prepare v0.1.1
## [0.1.0] - 2026-01-25

### 🚀 Features

- Init commit
- Add filter arg

### ⚙️ Miscellaneous Tasks

- Prepare v0.1.0
